The Tax Chamber is responsible for handling appeals against some decisions made by HMRC relating to Income Tax; PAYE tax; Corporation Tax; Capital Gains Tax; National Insurance Contributions; Statutory Sick Pay; Statutory Maternity Pay; Inheritance Tax; VAT; Excise Duty and Customs Duty.

They also handle some appeals relating to goods seized by either HM Revenue and Customs or Border Force and against some decisions made by the National Crime Agency and the Gambling Commission.

This tribunal began to regularly transfer decisions to The National Archives in 2022. The oldest decision from this tribunal included in Find Case Law is from {start_year}.

You can read more about it on the Tax Chamber page on the [HM Courts and Tribunals Service website](https://www.gov.uk/courts-tribunals/first-tier-tribunal-tax){target="\_blank"}.
